@@ -14,12 +14,9 @@ short_description = {
     "explain": lambda: _("Shows all the information about the last traceback."),
     "history": lambda: _("Shows a list of recorded traceback messages.")
     + " "
-    + _("You can also use `history.clear()` and `del history[index]`."),
+    + _("You can also use `history.clear()` and `history.pop()`."),
     "set_lang": lambda: _("Sets the language to be used."),
     "show_paths": lambda: _("Shows the paths corresponding to synonyms used."),
-    "toggle_prompt": lambda: _(
-        "Changes the prompt style to be used in the Friendly console."
-    ),
     "what": lambda: _("Shows the generic meaning of a given exception."),
     "where": lambda: _("Shows where an exception was raised."),
     "why": lambda: _("Shows the likely cause of the exception."),
@@ -37,13 +34,7 @@ short_description = {
     "set_formatter": lambda: _("Sets the formatter to use for display."),
     "set_debug": lambda: _("Use True (default) or False to enable debugging methods."),
     # The following are not translated by choice.
-    "_debug_tb": (
-        lambda: "Shows the full traceback, including code from friendly_traceback."
-    ),
     "_get_info": lambda: "Returns the content of the traceback items",
-    "_show_info": lambda: "Shows the all the items recorded in the traceback.",
-    "_get_exception": lambda: "Returns the exception instance.",
-    "_get_frame": lambda: "Returns the frame object where the exception occurred.",
     "_get_statement": lambda: "Returns a special Statement object for SyntaxError.",
     "_get_tb_data": lambda: "Return a special traceback object.",
 }
