@@ -1,3 +1,4 @@
+# sourcery skip: use-contextlib-suppress
 """info_variables.py
 
 Used to provide basic variable information in a way that
@@ -8,7 +9,7 @@ import builtins
 import re
 import sys
 import types
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Tuple, Union
 
 from . import debug_helper, token_utils, utils
 from .ft_gettext import current_lang
@@ -45,10 +46,7 @@ class ConfidentialInformation:
 
     def is_confidential(self, name: str) -> bool:
         """Identify variable names that are deemed to contain confidential information"""
-        for pattern in self.regex:
-            if re.fullmatch(pattern, name):
-                return True
-        return False
+        return any(re.fullmatch(pattern, name) for pattern in self.regex)
 
     def redact_confidential(self, name: str, value: Any) -> Any:
         if confidential.is_confidential(name):
@@ -80,7 +78,7 @@ def convert_type(short_form: str) -> str:
         "string": _("a string (`str`)"),
         "tuple": _("a `tuple`"),
     }
-    return forms.get(short_form, short_form)
+    return forms.get(short_form, f"`{short_form}`")
 
 
 def get_all_objects(line: str, frame: types.FrameType) -> ObjectsInfo:
@@ -108,17 +106,22 @@ def get_all_objects(line: str, frame: types.FrameType) -> ObjectsInfo:
         "name, obj": [],
         "name, type": [],
     }
+    names = set()
+    objects, names = find_identifiers(objects, line, frame, names)
+    return find_expressions(objects, line, frame, names)
 
+
+def find_identifiers(
+    objects: ObjectsInfo, line: str, frame: types.FrameType, names: set
+) -> Tuple[ObjectsInfo, set]:
+    """finds all the identifiers and corresponding objects"""
     scopes = (
         ("locals", frame.f_locals),  # always have locals before globals
         ("globals", frame.f_globals),
     )
-
-    names = set()
-
     tokens = token_utils.get_significant_tokens(line)
     if not tokens:
-        return objects
+        return objects, names
     for tok in tokens:
         if tok.is_identifier():
             name = tok.string
@@ -143,10 +146,19 @@ def get_all_objects(line: str, frame: types.FrameType) -> ObjectsInfo:
                     obj_type = type(obj).__name__
                     if obj_type is not None:
                         objects["name, type"].append((name, obj_type))
+    return objects, names
 
+
+def find_expressions(
+    objects: ObjectsInfo, line: str, frame: types.FrameType, names: set
+) -> ObjectsInfo:  # sourcery skip: simplify-generator, use-contextlib-suppress
+    """Use asttokens to find expressions of interest to include in variables shown."""
     line = line.strip()
-    if line.startswith(("def", "if", "while", "class", "for")) and line.endswith(":"):
+    if line.startswith(
+        ("def ", "if ", "while ", "class ", "for ", "with ")
+    ) and line.endswith(":"):
         line += " pass"
+
     try:
         atok = ASTTokens(line.strip(), parse=True)
     except SyntaxError as e:
@@ -159,6 +171,9 @@ def get_all_objects(line: str, frame: types.FrameType) -> ObjectsInfo:
             except SyntaxError as e:
                 debug_helper.log(f"Problem with ASTTokens: {e}" + f"\nline: {line}")
                 return objects
+        else:
+            debug_helper.log(f"Problem with ASTTokens: {e}" + f"\nline: {line}")
+            return objects
 
     if atok is not None:
         evaluator = Evaluator.from_frame(frame)
@@ -210,15 +225,30 @@ def get_object_from_name(name: str, frame: types.FrameType) -> Any:
     # We must guard against people defining their own type with a
     # standard name by checking standard types last.
 
+    # We will limit to only one dot i.e. 'name.attribute'
+    if "." in name:
+        if name.count(".") > 1:
+            print(name.count("."), name)
+            return None
+        name, attribute = name.replace(" ", "").split(".")
+    else:
+        attribute = None
+
     if name in frame.f_locals:
-        return frame.f_locals[name]
+        if attribute is None:
+            return frame.f_locals[name]
+        obj = frame.f_locals[name]
+        if hasattr(obj, attribute):
+            return getattr(obj, attribute)
 
     if name in frame.f_globals:
-        return frame.f_globals[name]
+        if attribute is None:
+            return frame.f_globals[name]
+        obj = frame.f_globals[name]
+        if hasattr(obj, attribute):
+            return getattr(obj, attribute)
 
-    if name in dir(builtins):  # Do this last
-        return getattr(builtins, name)
-    return None
+    return getattr(builtins, name) if name in dir(builtins) else None
 
 
 def get_variables_in_frame_by_scope(
@@ -362,9 +392,9 @@ def simplify_repr(value: str, splitlines: bool = True) -> str:
         path = path_utils.shorten_path(path[:-1])  # -1 removes >
         # Avoid lines that are too long
         if len(obj_repr) + len(path) > MAX_LENGTH and splitlines:
-            value = obj_repr + f">\n{INDENT}from " + path
+            value = f"{obj_repr}>\n{INDENT}from {path}"
         else:
-            value = obj_repr + "> from " + path
+            value = f"{obj_repr}> from {path}"
 
     # Replace some strings so that colour formatting is nicer
     value = value.replace("<class '", "<class ")
@@ -378,7 +408,7 @@ def simplify_repr(value: str, splitlines: bool = True) -> str:
         value = simplify_bound_method(value, splitlines=splitlines)
     elif ".<locals>." in value:
         parts = value.split(".<locals>.")
-        file_name = ".<locals>".join(parts[0:-1])
+        file_name = ".<locals>".join(parts[:-1])
         obj_name = parts[-1]
         if value.startswith("<function "):
             start = "<function "
@@ -399,25 +429,18 @@ def simplify_repr(value: str, splitlines: bool = True) -> str:
 
 
 def simplify_bound_method(name: str, splitlines: bool = False) -> str:
-    name = name[0:-1]  # remove final >
+    name = name[:-1]  # remove final >
     if ".<locals>." in name:
         method, obj = name.split(" of ")
         parts = method.split(".<locals>.")
         method = f"<bound method {parts[-1]}>"
         obj_parts = obj.split(".<locals>.")
+        file_name = ".<locals>".join(obj_parts[:-1])
         obj_name = obj_parts[-1]
-        file_name = ".<locals>".join(obj_parts[0:-1])
-        name = (
-            method
-            + " of <"
-            + obj_name
-            + "` defined in `<function "
-            + file_name[1:]
-            + ">"
-        )
+        name = f"{method} of <{obj_name}` defined in `<function {file_name[1:]}>"
         if len(name) > MAX_LENGTH and splitlines:
-            of_object = f"\n{INDENT}of <" + obj_name
-            defined_in = f"\n{INDENT}defined in <function " + file_name[1:] + ">"
+            of_object = f"\n{INDENT}of <{obj_name}"
+            defined_in = f"\n{INDENT}defined in <function {file_name[1:]}>"
             name = method + of_object + defined_in
     else:
         name = name.replace(" of", "> of")
@@ -477,7 +500,7 @@ def format_multiline(value: str) -> str:
     # This is useful for tabular data
     indent = "\n" + " " * 8
     lines = value.split("\n")
-    new_lines = [line if len(line) < 72 else line[:68] + "..." for line in lines]
+    new_lines = [line if len(line) < 72 else f"{line[:68]}..." for line in lines]
     if len(new_lines) > 6:
         new_lines = new_lines[:6] + ["..."]
     return indent + indent.join(new_lines)
@@ -494,14 +517,14 @@ def shorten_long_line(value: str, obj: str) -> (str, str):
         for part in parts:
             if len(part) + length > MAX_LENGTH:
                 break
-            new_parts.append(part + ", ")
+            new_parts.append(f"{part}, ")
             length += len(part) + 2
         if new_parts:
             value = "".join(new_parts) + "..." + value[-1]
         else:
-            value = value[0 : MAX_LENGTH - 5] + "..." + value[-1]
+            value = f"{value[:MAX_LENGTH - 5]}...{value[-1]}"
     else:
-        value = value[0 : MAX_LENGTH - 5] + "..." + value[-1]
+        value = f"{value[:MAX_LENGTH - 5]}...{value[-1]}"
     try:
         length_info = len(obj)
     except OverflowError:
@@ -528,6 +551,7 @@ def get_similar_names(name: str, frame: types.FrameType) -> SimilarNamesInfo:
     similar["locals"] = []
     similar["globals"] = []
     similar["builtins"] = []
+    similar["best"] = ""
     for word in all_similar:
         if word in locals_:
             similar["locals"].append(word)
@@ -538,14 +562,12 @@ def get_similar_names(name: str, frame: types.FrameType) -> SimilarNamesInfo:
     if all_similar:
         most_similar = utils.get_similar_words(name, all_similar)
         similar["best"] = most_similar[0]
-    elif name in ["length", "lenght"]:
+    elif name in {"length", "lenght"}:
         # utils.get_similar_words() used above only look for relatively
         # minor letter mismatches in making suggestions.
         # Here we add a few additional hard-coded cases.
         similar["builtins"] = ["len"]
         similar["best"] = "len"
-    else:
-        similar["best"] = None
     return similar
 
 
