@@ -90,18 +90,21 @@ def name_not_defined(message: str, tb_data: TracebackData) -> CauseInfo:
     )
 
     hint = ""
-    known_module = is_stdlib_module(unknown_name, tb_data)
+    known_module = is_stdlib_module(unknown_name)
     if known_module:
         cause = known_module["cause"]
         hint = known_module["suggest"]
 
     type_hint = info_variables.name_has_type_hint(unknown_name, frame)
     similar = info_variables.get_similar_names(unknown_name, frame)
-    if "lowercase" in known_module:
-        hint = _("Did you mean `{name}`?\n").format(name=unknown_name.lower())
-    elif similar["best"] is not None:
-        hint = _("Did you mean `{name}`?\n").format(name=similar["best"])
-    elif type_hint:
+    if similar["best"]:
+        if hint:
+            hint = hint.replace("\n", "") + _(" Or did you mean `{name}`?\n").format(
+                name=similar["best"]
+            )
+        else:
+            hint = _("Did you mean `{name}`?\n").format(name=similar["best"])
+    elif type_hint and not hint:
         hint = _("Did you use a colon instead of an equal sign?\n")
 
     additional = type_hint + format_similar_names(unknown_name, similar)
@@ -110,7 +113,7 @@ def name_not_defined(message: str, tb_data: TracebackData) -> CauseInfo:
         if more:
             additional += "\n" + more
     except Exception as e:  # pragma: no cover
-        debug_helper.log("Problem in name_not_defined()")
+        debug_helper.log("Problem in name_not_defined()/missing_self().")
         debug_helper.log_error(e)
 
     forgot_import = is_module_attribute(unknown_name)
@@ -197,7 +200,7 @@ def flipfloperator() -> CauseInfo:  # pragma: no cover
     return {"cause": cause, "suggest": hint}
 
 
-def is_stdlib_module(name: str, tb_data: TracebackData) -> CauseInfo:
+def is_stdlib_module(name: str) -> CauseInfo:
     """Determine if an unknown name is to be found in the Python standard library.
     We're looking for something like name.attribute"""
     # Some Python 2 libraries used names with uppercase letters.
