@@ -2,7 +2,6 @@
 
 import os
 import sys
-from types import FrameType
 from typing import TYPE_CHECKING, Any, Callable, Dict, List, Tuple, TypeVar, Union
 
 if TYPE_CHECKING:
@@ -71,7 +70,7 @@ if sys.version_info >= (3, 8):
         cause: str
         suggest: str
 
-    Site = Literal["friendly", "python", "bug", "email", "warnings"]
+    Site = Literal["friendly", "python", "bug", "email"]
 
     ScopeKind = Literal["local", "global", "nonlocal"]
 
@@ -87,7 +86,7 @@ if sys.version_info >= (3, 8):
     )
     SimilarNamesInfo = TypedDict(
         "SimilarNamesInfo",
-        {"locals": List[str], "globals": List[str], "builtins": List[str], "best": Any},
+        {"locals": List[str], "globals": List[str], "builtins": List[str], "best": str},
     )
 
 else:
@@ -101,11 +100,10 @@ else:
     SimilarNamesInfo = Dict[str, List[str]]
 
 
-Explain = Callable[[_E, FrameType, "TracebackData"], CauseInfo]
 GenericExplain = Callable[[], str]
 Parser = Union[
-    Callable[[str, FrameType, "TracebackData"], CauseInfo],
-    Callable[[_E, FrameType, "TracebackData"], CauseInfo],
+    Callable[[str, "TracebackData"], CauseInfo],
+    Callable[[_E, "TracebackData"], CauseInfo],
 ]
 Translator = Callable[[str], str]
 Writer = Callable[[str], None]
